@@ -13,14 +13,14 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 #{{{sub me_setup
 
 sub me_setup {
     my ($base_url) = @_;
     if ( !defined $base_url ) {
-        croak 'No base url to check existence against!';
+        croak 'No base url to run me against!';
     }
     return "get $base_url/system/me";
 }
@@ -41,7 +41,7 @@ sub me_eval {
 sub profile_update_setup {
     my ( $base_url, $field, $value, $act_on_user, $profile_section ) = @_;
     if ( !defined $base_url ) {
-        croak 'No base url to check existence against!';
+        croak 'No base url to run profile update against!';
     }
     if ( !defined $field ) {
         croak 'No profile field to update specified!';
@@ -57,8 +57,7 @@ sub profile_update_setup {
     }
     my $profile_update_json =
       "{\"elements\":{\"$field\":{\"value\":\"$value\"}}}";
-    my $post_variables = "\$post_variables =
-    [':content','$profile_update_json',':contentType','json',':operation','import',':removeTree','true',':replace','true',':replaceProperties','true']";
+    my $post_variables = "\$post_variables = [':content','$profile_update_json',':contentType','json',':operation','import',':removeTree','true',':replace','true',':replaceProperties','true']";
     return
 "post $base_url/~$act_on_user/public/authprofile/$profile_section.profile.json $post_variables";
 }
@@ -100,6 +99,17 @@ Inspects the result returned from issuing the request generated in me_setup
 returning true if the result indicates information was returned successfully,
 else false.
 
+=head2 profile_update_setup
+
+Returns a textual representation of the request needed to update the profile
+for a specified user.
+
+=head2 profile_update_eval
+
+Inspects the result returned from issuing the request generated in
+profile_setup returning true if the result indicates profile information was
+updated successfully, else false.
+
 =head1 USAGE
 
 use Sakai::Nakamura::UserUtil;
@@ -151,5 +161,5 @@ Daniel David Parry <perl@ddp.me.uk>
 
 LICENSE: http://dev.perl.org/licenses/artistic.html
 
-COPYRIGHT: (c) 2011 Daniel David Parry <perl@ddp.me.uk>
+COPYRIGHT: (c) 2012 Daniel David Parry <perl@ddp.me.uk>
 
